# CoolWorld

CoolWorld - Simplified Gaming Model.


## Introduction

CoolWorld is a **Python3** gaming library based on the concept of one
world containing many world items, all interacting one with another.

It supports only the essentials for making a world go playing with
external GUI libs such as Tkinter, PyGObject (GTK+), PySide, Pygame,
Pyglet, PySDL2 and so on.

This project is **freefullware** oriented (see [below](#freefullware)).


## License

    The MIT License (MIT)

    Copyright (c) 2015 Raphaël SEBAN

    Permission is hereby granted, free of charge, to any person
    obtaining a copy of this software and associated documentation
    files (the "Software"), to deal in the Software without
    restriction, including without limitation the rights to use, copy,
    modify, merge, publish, distribute, sublicense, and/or sell copies
    of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be
    included in all copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
    EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
    NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
    BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
    ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
    CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.


## Freefullware

What is a freefullware?

A **freefullware** is a new kind of software:

* Free as in Freedom;
* Free of charge (gratis);
* Ad-free (no advertisement at all);
* Donate-free (no 'Donate' button at all);
* 100% virus-free;
* no counterpart at all;
* really absolutely free;

Just get it and enjoy.

That's all, folks!


## Development status

At this stage, the project is in:

    Development Status :: 5 - Production/Stable


## Quick installation

On a Linux shell console:

    python3 /usr/bin/pip3 install -U CoolWorld

On a MS-DOS(tm) console prompt:

    C:\Python3.4\Scripts\pip3.exe install -U CoolWorld

Browse to your own Python3's pip3.exe installation path and adapt
command if this one doesn't work as expected.


## Basic usage

For a quick game demo (Linux shell console):

    python3
    >>> from CoolWorld import tkinter_ui
    >>> tkinter_ui.run_demo()

For a quick game demo (MS-DOS(tm) shell console):

    py -3
    >>> from CoolWorld import tkinter_ui
    >>> tkinter_ui.run_demo()

More generally, in a Python script file e.g. `test.py`:

```python
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from CoolWorld import game

class Player (game.WorldPlayer2D):

    def initialize (self):
        # put your own code here
        print("initializing", self.name)
        self.counter = 0
    # end def

    def do_step (self, *args, **kw):
        # put your own code here
        if self.counter < 10:
            self.counter += 1
            print("counting...", self.counter)
        else:
            # stop game right now
            self.world.end()
        # end if
    # end def

    def finalize (self):
        # put your own code here
        print("finalizing", self.name)
        del self.counter
    # end def

# end class

print("running game.")
world = game.World2D(area=(800, 600))
player = Player(world)
world.run(fps=5)
print("game ended.")
```


## Documentation

Reading the code directly is quite an enriching experience. :+1:

You may also try, in a Python interactive console:

    >>> from CoolWorld import world
    >>> help(world)
    >>> from CoolWorld import geometry
    >>> help(geometry)
    >>> ...etc...

Another way for getting automated documentation (in a shell console):

    pydoc3 -b

Have fun! :smiley_cat:
